@@ -160,6 +160,39 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
     return dataframe
 
 
+def get_npx_hitbtc_bindex_spread():
+    hbid, hask = fetch_rest_hitbtc_orderbook()
+    bbid, bask = fetch_rest_bindex_orderbook()
+    bnb = fetch_rest_crypto_compare_last_minute_ohlc('BNB','USDT')
+    eth = fetch_rest_crypto_compare_last_minute_ohlc('ETH','USDT')
+    return hbid, hask, bbid, bask, eth
+
+
+def fetch_rest_hitbtc_orderbook():
+    hitbtc_orderbook_url = 'https://api.hitbtc.com/api/2/public/orderbook/NPXETH'
+    # sending get request and saving the response as response object
+    r = requests.get(url=hitbtc_orderbook_url)
+    # extracting data in json format
+    data = r.json()
+    hitbtc_bids_df = pd.DataFrame(data['bid'])
+    hitbtc_asks_df = pd.DataFrame(data['ask'])
+    return hitbtc_bids_df, hitbtc_asks_df
+
+def fetch_rest_bindex_orderbook():
+    bindex_orderbook_url = 'https://dex.binance.org/api/v1/depth?symbol=NPXB-1E8_BNB'
+    # sending get request and saving the response as response object
+    r = requests.get(url=bindex_orderbook_url)
+    # extracting data in json format
+    data = r.json()
+
+    bindex_bids_df = pd.DataFrame(data['bids'])
+    bindex_asks_df = pd.DataFrame(data['asks'])
+
+    bindex_bids_df.columns = ['price', 'size']
+    bindex_asks_df.columns = ['price', 'size']
+    return bindex_bids_df, bindex_asks_df
+
+
 def fetch_rest_crypto_compare_last_minute_ohlc(ssj, against, limit = 1):
     last_minute_url = f'https://min-api.cryptocompare.com/data/v2/histominute?fsym={ssj}&tsym={against}&limit={limit}'
     r = requests.get(last_minute_url)
@@ -174,11 +207,46 @@ def fetch_rest_crypto_compare_last_minute_ohlc(ssj, against, limit = 1):
     dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
     dataframe = dataframe.set_index(dataframe['date'])
     dataframe = dataframe.drop(columns=['date'])
-
+    dataframe = dataframe.iloc[0]
     return dataframe
 
+def fetch_crypto_minutely_last_five_data(ssj=None, ssj_against='USDT', exchange = 'binance'):
+    year = datetime.datetime.now().year
+    month = datetime.datetime.now().month
+    day = datetime.datetime.now().day
+    hour = datetime.datetime.utcnow().hour
+    ts = datetime.datetime(year, month, day, tzinfo=datetime.timezone.utc).timestamp() + hour * 3600
+    ts1 = ts - 2001 * 60
+    ts2 = ts1 - 2001 * 60
+    ts3 = ts2 - 2001 * 60
+    ts4 = ts3 - 2001 * 60
+    ts5 = ts4 - 2001 * 60
+    ts6 = ts5 - 2001 * 60
+    ts7 = ts6 - 2001 * 60
+    ts8 = ts7 - 2001 * 60
+    ts9 = ts8 - 2001 * 60
+    ts10 = ts9 - 2001 * 60
+    ts11 = ts10 - 2001 * 60
+    ts12 = ts11 - 2001 * 60
+    print('Loading data')
+    binance_min_usdt_url = 'https://min-api.cryptocompare.com/data/v2/histominute?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
 
+    dataframe = None
+    for me_timestamp in [ts12,ts11,ts10,ts9,ts8,ts7,ts6,ts5,ts4,ts3,ts2,ts1,ts]:
+        print('waiting')
+        df = request_minute_data_paquet(binance_min_usdt_url, me_timestamp, ssj)
+        if df is not None:
+            if dataframe is not None:
+                dataframe = dataframe.append(df, ignore_index=True)
+            else:
+                dataframe = df.copy()
 
+    dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
+    dataframe = dataframe.sort_values(by=['time'])
+    dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
+    dataframe = dataframe.set_index(dataframe['date'])
+    dataframe = dataframe.drop(columns=['date'])
+    return dataframe
 
 def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, refetch_all=True, ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
