@@ -666,10 +666,73 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
     # ohlc_bnb_binance (minutes)
     ohlc_bnb_min_binance = ohlc_bnb_min_binance.set_index('ts')
+
+
     assert isinstance(ohlc_bnb_min_binance.index, pd.DatetimeIndex)
-    ohlc_bnb_min_binance.columns = [x + '_bnb_bnc' for x in ohlc_bnb_min_binance.columns]
+
     ohlc_bnb_min_binance.index = ohlc_bnb_min_binance.index.tz_localize(None)
 
+#################################
+    ###########
+    ############  ########### converting trades commission
+    trades['ts'] = pd.to_datetime(trades['ts'])
+    def round_to_the_minute(row):
+        new_date = datetime.datetime(year=row['ts'].year, month = row['ts'].month, day =row['ts'].day, minute= row['ts'].minute)
+        return new_date
+    trades['min_ts'] = trades.apply(round_to_the_minute,axis=1)
+    trades = pd.merge(trades, ohlc_bnb_min_binance[['open']],left_on='min_ts',right_index=True)
+
+    trades = trades.rename(columns = {'open':'open_bnb'})
+    trades['commission'] = trades['commission'].astype(float)
+    trades['open_bnb'] = trades['open_bnb'].astype(float)
+    def converted_commission_fee(row):
+        if row['commissionAsset'] == 'BNB':
+            return row['commission']*row['open_bnb']
+        else :
+            return row['commission']
+
+    trades['converted_commission'] = trades.apply(converted_commission_fee, axis=1)
+    trades = trades.rename(columns ={
+        'commission':'unconverted_commission'
+    })
+    trades = trades.rename(columns ={
+        'converted_commission':'commission',
+    })
+
+    #################################
+    ###########
+    ############  ########### converting walletHist
+    walletHist['ts'] = pd.to_datetime(walletHist['ts'])
+
+    def round_to_the_minute(row):
+        new_date = datetime.datetime(year=row['ts'].year, month=row['ts'].month, day=row['ts'].day,
+                                     minute=row['ts'].minute)
+        return new_date
+
+    walletHist['min_ts'] = walletHist.apply(round_to_the_minute, axis=1)
+    walletHist = pd.merge(walletHist, ohlc_bnb_min_binance[['open']], left_on='min_ts', right_index=True)
+
+    walletHist = walletHist.rename(columns={'open': 'open_bnb'})
+    walletHist['income'] = walletHist['income'].astype(float)
+    walletHist['open_bnb'] = walletHist['open_bnb'].astype(float)
+
+    def converted_commission_fee(row):
+        if row['asset'] == 'BNB':
+            return row['income'] * row['open_bnb']
+        else:
+            return row['income']
+
+    walletHist['converted_income'] = walletHist.apply(converted_commission_fee, axis=1)
+    walletHist = walletHist.rename(columns ={
+        'income':'unconverted_income'
+    })
+    walletHist = walletHist.rename(columns ={
+        'converted_income':'income',
+    })
+
+    ############
+    ohlc_bnb_min_binance.columns = [x + '_bnb_bnc' for x in ohlc_bnb_min_binance.columns]
+    ###########@
     def filter_me_month(data_df, filtering_month):
         if filtering_month == 0:
             filtering_month=12
@@ -720,6 +783,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
         'qty': 'Amount',
         'price': 'Price',
         'commission': 'Fees',
+        'unconverted_commission' :'Unconverted fees',
         'ts': 'Date'
     })
 
@@ -737,7 +801,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
             return np.nan
 
 
-    trades_columns = ['Nature', 'Security Code', 'Currency', 'Oper', 'Date', 'Amount', 'Price', 'PnL', 'Fees']
+    trades_columns = ['Nature', 'Security Code', 'Currency', 'Oper', 'Date', 'Amount', 'Price', 'PnL', 'Fees', 'Unconverted fees','min_ts','open_bnb']
     trades_df = trades_df[trades_columns]
     trades_df['Security Code'] = trades_df.apply(convert_symbol, axis=1)
 
@@ -837,7 +901,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     ]
     b40_cols = ['Nature', 'Security Code', 'Currency', 'Description', 'Comment', 'Oper', 'Date', 'Value', 'Settlement',
                 'Amount', 'Price', 'Int. Rate', 'Meth', 'Excl', 'Last Coupon', 'Interest', 'Depo', 'Bank', 'Pmt Cur',
-                'Source',	'Investor', 'Fees', 'Bank']
+                'Source',	'Investor', 'Fees', 'Unconverted fees','Bank','min_ts','open_bnb']
 
 
     for me_col in b40_cols:
@@ -872,8 +936,8 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     filtered_binance_df['Source'] = 'Manual'
 
     filtered_binance_df['Currency'] = 'UST'
-
-    filtered_binance_df.iloc[:,len(filtered_binance_df.columns)-1]=''
+    #
+    # filtered_binance_df.iloc[:,len(filtered_binance_df.columns)-1]=''
 
     funding_df['Date'] = funding_df['Date'].dt.strftime('%d/%m/%Y')
 
